==> 0.0.1%2B1.tar.gz: lib/models/IR5Image.dart <==
// --------------------------------------------------------------------------------

import 'package:json_annotation/json_annotation.dart';

part 'IR5Image.g.dart';

@JsonSerializable()
class IR5Image {
  IR5Image({
    required this.Num,
    required this.Nom,
    required this.Description,
    required this.ImgTypes,
    required this.FileExt,
    required this.ContentType,
    required this.Width,
    required this.Height,
    required this.Img,
    required this.Img2,
    required this.Img3,
    required this.Img4,
  });

  factory IR5Image.fromJson(Map<String, dynamic>? json) => _$IR5ImageFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ImageToJson(this);

  @JsonKey(defaultValue: 0)
  final num Num;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: '')
  final String Description;

  /** Image Types
   *   Bit 00 : Image Salles (value:1)
   *   Bit 01 : Image Tables (value:2)
   *   Bit 02 : Image ModePay (140x70) (value:4)
   *   Bit 03 : Staff Icons (40x40) (value:8)
   *   Bit 04 : Image Btns (value:16)
   *   Bit 05 : Info Image (value:32)
   *   Bit 06 : Logo (value:64)
   */
  @JsonKey(defaultValue: 0)
  final num ImgTypes;
  @JsonKey(defaultValue: '')
  final String FileExt;
  @JsonKey(defaultValue: '')
  final String ContentType;
  @JsonKey(defaultValue: 0)
  final num Width;
  @JsonKey(defaultValue: 0)
  final num Height;
  @JsonKey(defaultValue: '')
  final String Img;
  @JsonKey(defaultValue: '')
  final String Img2;
  @JsonKey(defaultValue: '')
  final String Img3;
  @JsonKey(defaultValue: '')
  final String Img4;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Image.dart <==
// --------------------------------------------------------------------------------

import 'package:json_annotation/json_annotation.dart';

part 'IR5Image.g.dart';

@JsonSerializable()
class IR5Image {
  IR5Image({
    required this.Num,
    required this.Nom,
    required this.Description,
    required this.ImgTypes,
    required this.FileExt,
    required this.ContentType,
    required this.Width,
    required this.Height,
    required this.Img,
    required this.Img2,
    required this.Img3,
    required this.Img4,
  });

  factory IR5Image.fromJson(Map<String, dynamic>? json) =>
      _$IR5ImageFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ImageToJson(this);

  @JsonKey(defaultValue: 0)
  final num Num;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: '')
  final String Description;

  /** Image Types
   *   Bit 00 : Image Salles (value:1)
   *   Bit 01 : Image Tables (value:2)
   *   Bit 02 : Image ModePay (140x70) (value:4)
   *   Bit 03 : Staff Icons (40x40) (value:8)
   *   Bit 04 : Image Btns (value:16)
   *   Bit 05 : Info Image (value:32)
   *   Bit 06 : Logo (value:64)
   */
  @JsonKey(defaultValue: 0)
  final num ImgTypes;
  @JsonKey(defaultValue: '')
  final String FileExt;
  @JsonKey(defaultValue: '')
  final String ContentType;
  @JsonKey(defaultValue: 0)
  final num Width;
  @JsonKey(defaultValue: 0)
  final num Height;
  @JsonKey(defaultValue: '')
  final String Img;
  @JsonKey(defaultValue: '')
  final String Img2;
  @JsonKey(defaultValue: '')
  final String Img3;
  @JsonKey(defaultValue: '')
  final String Img4;
}
